FABIA
=====
Fabia is a biclustering algorithm based on matrix factorization, first
published in:

*FABIA: Factor Analysis for Bicluster Acquisition*, Sepp Hochreiter et al,  Bioinformatics 2010


This implementation conforms to the scikit-learn biclustering API.
It requires scipy 0.16 or higher, scikit-learn >= 0.16 as well as Cython to work.


License
-------
this package is licensed under a GPL v2 license.
